@@ -95,9 +95,24 @@ pub struct GenerateArgs {
     pub force: bool,
 
     /// Enables more verbose output.
-    #[arg(long, short, action)]
+    #[arg(long, short, action, conflicts_with = "quiet")]
     pub verbose: bool,
 
+    /// Opposite of verbose, suppresses errors & warning in output
+    /// Conflicts with verbose, and requires the use of --continue-on-error
+    #[arg(
+        long,
+        short,
+        action,
+        conflicts_with = "verbose",
+        requires = "continue_on_error"
+    )]
+    pub quiet: bool,
+
+    /// Continue if errors in templates are encountered
+    #[arg(long, action)]
+    pub continue_on_error: bool,
+
     /// Pass template values through a file. Values should be in the format `key=value`, one per
     /// line
     #[arg(long="values-file", value_parser, alias="template-values-file", value_name="FILE", help_heading = heading::OUTPUT_PARAMETERS)]
@@ -177,6 +192,8 @@ impl Default for GenerateArgs {
             name: None,
             force: false,
             verbose: false,
+            quiet: false,
+            continue_on_error: false,
             template_values_file: None,
             silent: false,
             config: None,
@@ -210,6 +227,7 @@ pub struct TemplatePath {
 
     /// Expand $CWD as a template, then run `cargo test` on the expansion (set
     /// $CARGO_GENERATE_TEST_CMD to override test command).
+    /// implies --verbose
     ///
     /// Any arguments given after the `--test` argument, will be used as arguments for the test
     /// command.
